<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
		xmlns:xlink="http://www.w3.org/1999/xlink"
    xmlns:d="http://docbook.org/ns/docbook">
  
  <xsl:import href="../../docbook-xsl/xhtml/chunk.xsl"/>
  <xsl:import href="../../docbook-xsl/xhtml/highlight.xsl"/>
  <xsl:import href="../../docbook-xsl/webhelp/xsl/webhelp-common.xsl"/>
  <xsl:import href="../../docbook-xsl/webhelp/xsl/titlepage.templates.xsl"/>
  
  <xsl:import href="../Common/common.xsl"/>

  <xsl:template match="/">    

    <xsl:for-each select="//d:chapter[contains(@annotations, 'slide')]|
                          //d:section[contains(@annotations, 'slide')]">
      <xsl:call-template name="slideUnit">
        <xsl:with-param name="rootId" select="@xml:id"/>
        <xsl:with-param name="sections" select="."/>
      </xsl:call-template>
    </xsl:for-each>
    

    <xsl:for-each select="//d:chapter[descendant::*[contains(@annotations, 'slide')]]|
                          //d:section[descendant::*[contains(@annotations, 'slide')]]">
      <xsl:call-template name="slideUnit">
        <xsl:with-param name="rootId" select="@xml:id"/>
        <xsl:with-param name="sections" select="descendant::*[contains(@annotations, 'slide')]"/>
      </xsl:call-template>
    </xsl:for-each>
    
  </xsl:template>
  
  <xsl:template name="slideUnit">
    <xsl:param name="rootId"/>
    <xsl:param name="sections"/>

    <xsl:document href="__slide{$rootId}.html" method="html" encoding="utf-8" indent="no">
        
      <html lang="en">
        <head>
          <title>
            <xsl:value-of select="d:title"/>
          </title>
          <link href="common/css/positioning.css" rel="stylesheet" />
          <link href="reveal.js/css/reveal.css" rel="stylesheet" />
          <link href="reveal.js/css/theme/solarized.css" id="theme" rel="stylesheet" />
          
          <!-- Code syntax highlighting -->
          <link href="reveal.js/lib/css/zenburn.css" rel="stylesheet" />
          
        </head>
        
        <body>
          <!-- Wrap the entire slide show in a div using the "reveal" class. -->
          <div class="reveal">
            <!-- Wrap all slides in a single "slides" class -->
            <div class="slides">
              <xsl:apply-templates select="$sections" mode="slideDescendants"/>
            </div>
          </div>
          
          <script src="reveal.js/lib/js/head.min.js"></script>
          <script src="reveal.js/js/reveal.js"></script>
          <script>/*<![CDATA[*/
            
            Reveal.initialize({
            controls: true,
            progress: true,
            history: true,
            center: true,
            width: '70%',
	          margin: 0.0,
            
            transition: 'slide', // none/fade/slide/convex/concave/zoom
            
            math: {
            mathjax: 'mathjax/MathJax.js',
            config: 'TeX-AMS-MML_HTMLorMML',  // See http://docs.mathjax.org/en/latest/config-files.html
            },
            // Optional reveal.js plugins
            dependencies: [
            { src: 'reveal.js/lib/js/classList.js', condition: function() { return !document.body.classList; } },
            { src: 'reveal.js/plugin/markdown/marked.js', condition: function() { return !!document.querySelector( '[data-markdown]' ); } },
            { src: 'reveal.js/plugin/markdown/markdown.js', condition: function() { return !!document.querySelector( '[data-markdown]' ); } },
            { src: 'reveal.js/plugin/highlight/highlight.js', async: true, callback: function() { hljs.initHighlightingOnLoad(); } },
            { src: 'reveal.js/plugin/zoom-js/zoom.js', async: true },
            { src: 'reveal.js/plugin/notes/notes.js', async: true },
            { src: 'reveal.js/plugin/math/math.js', async: true }
            ]
            });
            /*]]>*/</script>
        </body>
      </html>
    </xsl:document>
  </xsl:template>
  
  <xsl:template match="d:chapter|d:section" mode="slideDescendants">
    <xsl:apply-templates select="d:section|d:figure"  mode="slideDescendants"/>
  </xsl:template>
  
  <xsl:template match="d:title" mode="slideDescendants"/>
  
  <xsl:template match="*" mode="slideDescendants">
    <section>
      <xsl:attribute name="xml:id">
        <xsl:choose>
          <xsl:when test="@xml:id"><xsl:value-of select="@xml:id"/></xsl:when>
          <xsl:otherwise><xsl:value-of select="generate-id(.)"/></xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      
      <xsl:apply-templates select="."/>
      <a style="font-size: 50%">
        <xsl:attribute name="href">
          <xsl:call-template name="href.target.uri"/>
        </xsl:attribute>
        <xsl:text>Back</xsl:text>
      </a>
    </section>
  </xsl:template>
  
  
  <!-- Get rid of block object names e.g. "Figure 3.1" -->
  <xsl:template match="d:figure">
    <xsl:apply-templates/>
  </xsl:template>
  
  <xsl:template match="d:figure/d:title">
    <h3>
      <xsl:apply-templates/>
    </h3>
  </xsl:template>
  
  <!-- Hack: Docbook XSL does not handle @valign in images-->  
  <xsl:template match="d:mediaobject[d:imageobject/d:imagedata[@valign]]">
    <img src="{d:imageobject/d:imagedata/@fileref}">
      <xsl:attribute name="style">
        <xsl:variable name="dbValign" select="d:imageobject/d:imagedata/@valign"/>
        
        <xsl:text>vertical-align: </xsl:text>
        <xsl:choose>
          <xsl:when test="$dbValign = 'top'">text-top</xsl:when>
          <xsl:when test="$dbValign = 'middle'">middle</xsl:when>
          <xsl:when test="$dbValign = 'bottom'">text-bottom</xsl:when>
          <xsl:otherwise>
            <xsl:message>
              <xsl:text>Unknown @valign value: </xsl:text>
              <xsl:value-of select="$dbValign"/>
            </xsl:message>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
    </img>
    
  </xsl:template>
  
</xsl:stylesheet>
